@@ -409,7 +409,7 @@ def _find(observer, target, start_time, end_time, horizon_degrees, f):
         timebump = ha_adjustment / ha_per_day
         t = ts.tt_jd(t.whole, t.tt_fraction + timebump)
 
-    is_above_horizon = (desired_ha != 0.0)
+    is_above_horizon = (desired_ha % pi != 0.0)
     return t, is_above_horizon
 
 def find_risings(observer, target, start_time, end_time, horizon_degrees=None):
@@ -423,8 +423,8 @@ def find_risings(observer, target, start_time, end_time, horizon_degrees=None):
     the target really crosses the horizon, and ``False`` when the target
     merely transits without actually touching the horizon.
 
-    See :ref:`horizon_degrees` for how to use the ``horizon_degrees``
-    argument.
+    See `risings-and-settings` for examples, and `horizon_degrees` for
+    how to use the ``horizon_degrees`` argument.
 
     .. versionadded:: 1.47
 
@@ -443,8 +443,8 @@ def find_settings(observer, target, start_time, end_time, horizon_degrees=None):
     the target really crosses the horizon, and ``False`` when the target
     merely transits without actually touching the horizon.
 
-    See :ref:`horizon_degrees` for how to use the ``horizon_degrees``
-    argument.
+    See `risings-and-settings` for examples, and `horizon_degrees` for
+    how to use the ``horizon_degrees`` argument.
 
     .. versionadded:: 1.47
 
@@ -461,6 +461,8 @@ def find_transits(observer, target, start_time, end_time):
     listing the moments at which the target transits across the
     meridian.
 
+    See `transits` for example code.
+
     .. versionadded:: 1.47
 
     """
